---
name: "\U0001F41B Bug report"
about: Create a report to help us improve
title: "[Bug]"
labels: bug
assignees: ''

---

# 🐛 Bug

<!-- A clear and concise description of what the bug is. -->

## To reproduce

** Code snippet to reproduce **
```python
# Your code goes here
# Please make sure it does not require any external dependencies (other than PyTorch!)
# (We much prefer small snippets rather than links to existing libraries!)
```

** Stack trace/error message **
```
// Paste the bad output here!
```

## Expected Behavior

<!-- A clear and concise description of what you expected to happen. -->

## System information

**Please complete the following information:**
- <!-- GPyTorch Version (run `print(gpytorch.__version__)` -->
- <!-- PyTorch Version (run `print(torch.__version__)` -->
- <!-- Computer OS -->

## Additional context
Add any other context about the problem here.
